@@ -12,36 +12,38 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('bernouilli',nbNodes, FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', -10    , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', c(1,2) , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix( 2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(0, nbBlocks - 1, nbBlocks))))
+  mySampler <- SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('bernouilli',nbNodes, FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', -10    , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', c(1,2) , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, -2, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix( 2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(0, nbBlocks - 1, nbBlocks))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'bernoulli')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  ## draw some parameters
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
   expect_true(all(mySampler$expectation <= 1, na.rm = TRUE))
-  expect_true(isSymmetric(mySampler$netMatrix))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
+  expect_true(isSymmetric(mySampler$networkData))
+  expect_true(all(is.na(diag(mySampler$networkData))))
   expect_true(!mySampler$directed)
 
   ## blocks
@@ -55,6 +57,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
@@ -65,36 +68,37 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('bernouilli',nbNodes, TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernouilli',nbNodes, FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', -10    , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', c(1,2) , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix( 2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix(0, nbBlocks - 1, nbBlocks))))
+  mySampler <- SimpleSBM$new('bernoulli', nbNodes, TRUE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('bernouilli',nbNodes, TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernouilli',nbNodes, FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', -10    , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', c(1,2) , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, TRUE, -2, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, TRUE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix( 2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, TRUE, blockProp, list(mean = matrix(0, nbBlocks - 1, nbBlocks))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'bernoulli')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1))
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
   expect_true(all(mySampler$expectation <= 1, na.rm = TRUE))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
-  expect_true(!isSymmetric(mySampler$netMatrix))
+  expect_true(all(is.na(diag(mySampler$networkData))))
+  expect_true(!isSymmetric(mySampler$networkData))
   expect_true(mySampler$directed)
 
   ## blocks
@@ -108,6 +112,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
@@ -118,34 +123,35 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('poison' , nbNodes, FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', -10    , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', c(1,2) , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, FALSE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, FALSE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, list(mean = round(40 * matrix(runif(nbBlocks**2), nbBlocks, nbBlocks)))))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, FALSE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks))))
+  mySampler <- SimpleSBM$new('poisson', nbNodes, FALSE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('poison' , nbNodes, FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', -10    , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', c(1,2) , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, FALSE, -2, connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, FALSE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, FALSE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('poisson', nbNodes, FALSE, blockProp, list(mean = round(40 * matrix(runif(nbBlocks**2), nbBlocks, nbBlocks)))))
+  expect_error(SimpleSBM$new('poisson', nbNodes, FALSE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'poisson')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
-  expect_true(isSymmetric(mySampler$netMatrix))
+  expect_true(all(is.na(diag(mySampler$networkData))))
+  expect_true(isSymmetric(mySampler$networkData))
 
   ## blocks
   expect_equal(mySampler$blockProp, blockProp)
@@ -158,6 +164,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
@@ -169,33 +176,34 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('poisson', nbNodes, TRUE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('poison' , nbNodes, TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', -10    , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', c(1,2) , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, TRUE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, TRUE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, TRUE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('poisson', nbNodes, TRUE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks))))
+  mySampler <- SimpleSBM$new('poisson', nbNodes, TRUE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('poison' , nbNodes, TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', -10    , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', c(1,2) , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, TRUE, -2, connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, TRUE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('poisson', nbNodes, TRUE, blockProp, list(mean = matrix(-2, nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('poisson', nbNodes, TRUE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'poisson')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1))
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
-  expect_true(!isSymmetric(mySampler$netMatrix))
+  expect_true(all(is.na(diag(mySampler$networkData))))
+  expect_true(!isSymmetric(mySampler$networkData))
   expect_true(mySampler$directed)
 
   ## blocks
@@ -209,6 +217,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
@@ -220,33 +229,34 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means, var = 2)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('normal'  , nbNodes, FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', -10    , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', c(1,2) , FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, list(mean = means, var = -1)))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks), var = 1)))
+  mySampler <- SimpleSBM$new('gaussian', nbNodes, FALSE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('normal'  , nbNodes, FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', -10    , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', c(1,2) , FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE, -2, connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE, blockProp, list(mean = means, var = -1)))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE, blockProp, list(mean = matrix(2 , nbBlocks - 1, nbBlocks), var = 1)))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'gaussian')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1)/2)
   expect_equal(mySampler$connectParam$mean, means)
   expect_equal(mySampler$connectParam$var, 2)
+
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
-  expect_true(isSymmetric(mySampler$netMatrix))
+  expect_true(all(is.na(diag(mySampler$networkData))))
+  expect_true(isSymmetric(mySampler$networkData))
 
   ## blocks
   expect_equal(mySampler$blockProp, blockProp)
@@ -259,6 +269,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
@@ -269,33 +280,34 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   connectParam <- list(mean = means, var = 2)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('normal'  , nbNodes, TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, FALSE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', -10    , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', c(1,2) , TRUE, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, -2, connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, TRUE,  c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, blockProp, list(var = -1, mean = means)))
-  expect_error(SimpleSBM_sampler$new('gaussian', nbNodes, TRUE, blockProp, list(var = 1, mean = matrix(2 , nbBlocks - 1, nbBlocks))))
+  mySampler <- SimpleSBM$new('gaussian', nbNodes, TRUE, blockProp, connectParam)
+  expect_error(SimpleSBM$new('normal'  , nbNodes, TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, FALSE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', -10    , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', c(1,2) , TRUE, blockProp, connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, TRUE, -2, connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, TRUE,  c(0,1), connectParam))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, TRUE, blockProp, list(var = -1, mean = means)))
+  expect_error(SimpleSBM$new('gaussian', nbNodes, TRUE, blockProp, list(var = 1, mean = matrix(2 , nbBlocks - 1, nbBlocks))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "SimpleSBM_sampler"))
+  expect_true(inherits(mySampler, "SimpleSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'gaussian')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, c(nbNodes, nbNodes))
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes*(nbNodes - 1))
   expect_equal(mySampler$connectParam$mean, means)
   expect_equal(mySampler$connectParam$var, 2)
+
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), c(nbNodes, nbNodes))
-  expect_true(all(is.na(diag(mySampler$netMatrix))))
-  expect_true(!isSymmetric(mySampler$netMatrix))
+  expect_true(all(is.na(diag(mySampler$networkData))))
+  expect_true(!isSymmetric(mySampler$networkData))
   expect_true(mySampler$directed)
 
   ## blocks
@@ -309,6 +321,7 @@ test_that("Construction, fields access and other basics work in class SimpleSBM_
   expect_equal(mySampler$nbCovariates, 0)
   expect_equal(mySampler$covarList, list())
   expect_equal(mySampler$covarParam, numeric(0))
+  expect_equal(mySampler$covarEffect, numeric(0))
 
 })
 
